@@ -323,8 +323,14 @@ CDox::~CDox()
 
   qstring_save (recent_list_fname, recent_files.join ("\n"));
 
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
+
+//#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+#if defined(JOYSTICK_SUPPORTED)
+
   delete joystick;
+//#endif
+
 #endif
 }
 
@@ -891,7 +897,11 @@ CDox::CDox()
   timer = new QTimer (this);
   timer->setInterval (100);
 
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
+
+//#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+#if defined(JOYSTICK_SUPPORTED)
+
   joystick = new CJoystick (0, this);
 
   if (joystick->initialized)
@@ -901,6 +911,7 @@ CDox::CDox()
       if (settings->value ("use_joystick", "0").toInt())
          timer->start();
      }
+//#endif
 #endif
 }
 
@@ -2165,8 +2176,6 @@ void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
 
 */
 
- // int y = textCursor().block().blockNumber();
- // int x = textCursor().position() - textCursor().block().position();
  
   int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
   int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
@@ -2175,15 +2184,11 @@ void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
   
   int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
   int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
-  //int xdiff = x2 - x1;
   
-  int how_many_copy_from_source = ydiff;
+//  int how_many_copy_from_source = ydiff;
   
-  int lines_to_end = blockCount() - y1;
-  
-  if (ydiff > lines_to_end)
-     how_many_copy_from_source = lines_to_end;
-     
+//  int lines_to_end = blockCount() - y1;
+      
   QStringList sl_source;
   
   for (int line = y1; line <= y2; line++)
@@ -2632,8 +2637,11 @@ void CSyntaxHighlighter::highlightBlock (const QString &text)
         }
 }
 */
+//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
+
+//#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
+#if defined(JOYSTICK_SUPPORTED)
 
-#if defined(Q_OS_LINUX) || defined(Q_WS_X11) 
 bool CDox::event (QEvent *ev)
 {
 
@@ -2682,7 +2690,7 @@ void CDox::handle_joystick_event (CJoystickAxisEvent *event)
 }    
 
 #endif
-
+//#endif
 
 void CDox::update_project (const QString &fileName)
 {
